==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/bg/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Потвърдете масовото изтриване на активи',
  'bulk_delete_help'	=> 'Прегледайте активите, маркирани за масово изтриване. Веднъж изтрити, активите могат да бъдат възстановени, но те вече няма да бъдат асоциирани с потребителите, на които са изписани в момента.',
  'bulk_delete_warn'	=> 'Ще бъдат изтрити :asset_count актива.',
	'bulk_update'		=> 'Масово обновяване на активи',
	'bulk_update_help'	=> 'Тук можете да обновите множество активи едновременно. Попълнете единствено полетата, които желаете да промените. Всички празни полета няма да бъдат променени.',
	'bulk_update_warn'	=> 'Ще бъдат променени записите за :asset_count актива.',
    'checkedout_to'		=> 'Изписано на',
    'checkout_date'		=> 'Дата на изписване',
    'checkin_date'		=> 'Дата на вписване',
    'checkout_to'		=> 'Изпиши на',
    'cost'				=> 'Стойност на закупуване',
    'create'			=> 'Създаване на актив',
    'date'				=> 'Дата на закупуване',
    'depreciation'	    => 'амортизация',
    'depreciates_on'	=> 'Амортизира се на',
    'default_location'	=> 'Местоположение по подразбиране',
    'eol_date'			=> 'EOL дата',
    'eol_rate'			=> 'EOL съотношение',
    'expected_checkin'  => 'Очаквана дата на вписване',
    'expires'			=> 'Изтича',
    'fully_depreciated'	=> 'Напълно амортизиран',
    'help_checkout'		=> 'Ако желаете да присвоите актив на момента, изберете "Готово за предаване" от списъка по-горе.',
    'mac_address'		=> 'MAC адрес',
    'manufacturer'		=> 'Производител',
    'model'				=> 'Модел',
    'months'			=> 'месеца',
    'name'				=> 'Име на актив',
    'notes'				=> 'Бележки',
    'order'				=> 'Номер на поръчка',
    'qr'				=> 'QR код',
    'requestable'		=> 'Потребителите могат да изписват актива',
    'select_statustype'	=> 'Избиране на тип на статуса',
    'serial'			=> 'Сериен номер',
    'status'			=> 'Статус',
    'tag'				=> 'Инвентарен номер',
    'update'			=> 'Обновяване на актив',
    'warranty'			=> 'Гаранция',
		'warranty_expires'		=> 'Гаранцията изтича',
    'years'				=> 'години',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/bg/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Потвърдете масовото изтриване на активи',
  'bulk_delete_help'	=> 'Прегледайте активите, маркирани за масово изтриване. Веднъж изтрити, активите могат да бъдат възстановени, но те вече няма да бъдат асоциирани с потребителите, на които са изписани в момента.',
  'bulk_delete_warn'	=> 'Ще бъдат изтрити :asset_count актива.',
    'bulk_update'		=> 'Масово обновяване на активи',
    'bulk_update_help'	=> 'Тук можете да обновите множество активи едновременно. Попълнете единствено полетата, които желаете да промените. Всички празни полета няма да бъдат променени.',
    'bulk_update_warn'	=> 'Ще бъдат променени записите за :asset_count актива.',
    'checkedout_to'		=> 'Изписано на',
    'checkout_date'		=> 'Дата на изписване',
    'checkin_date'		=> 'Дата на вписване',
    'checkout_to'		=> 'Изпиши на',
    'cost'				=> 'Стойност на закупуване',
    'create'			=> 'Създаване на актив',
    'date'				=> 'Дата на закупуване',
    'depreciation'	    => 'амортизация',
    'depreciates_on'	=> 'Амортизира се на',
    'default_location'	=> 'Местоположение по подразбиране',
    'eol_date'			=> 'EOL дата',
    'eol_rate'			=> 'EOL съотношение',
    'expected_checkin'  => 'Очаквана дата на вписване',
    'expires'			=> 'Изтича',
    'fully_depreciated'	=> 'Напълно амортизиран',
    'help_checkout'		=> 'Ако желаете да присвоите актив на момента, изберете "Готово за предаване" от списъка по-горе.',
    'mac_address'		=> 'MAC адрес',
    'manufacturer'		=> 'Производител',
    'model'				=> 'Модел',
    'months'			=> 'месеца',
    'name'				=> 'Име на актив',
    'notes'				=> 'Бележки',
    'order'				=> 'Номер на поръчка',
    'qr'				=> 'QR код',
    'requestable'		=> 'Потребителите могат да изписват актива',
    'select_statustype'	=> 'Избиране на тип на статуса',
    'serial'			=> 'Сериен номер',
    'status'			=> 'Статус',
    'tag'				=> 'Инвентарен номер',
    'update'			=> 'Обновяване на актив',
    'warranty'			=> 'Гаранция',
        'warranty_expires'		=> 'Гаранцията изтича',
    'years'				=> 'години',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
